@@ -39,6 +39,7 @@ from collections import Counter, OrderedDict
 from .common import put_txt_with_newline
 from .get_dataset_label_map import coco_label_map_list
 from .constants import light_colors
+from .common import global_random_choices_for_u, dynamic_cls_name_color_map
 
 
 def _draw_round_dot_border(img, pt1, pt2, color, thickness, r=2, d=5):
@@ -475,10 +476,11 @@ def visualize_det_cv2_part(
     style="none",
     force_color=None,
     line_thickness=2,
-    font_scale=0.58,
+    font_scale=0.41,
     show_time=0,
     wait_t=0,
     transparent=False,
+    score_percent=False,
 ):
     """
     visualize detection on image using cv2, this is the standard way to visualize detections
@@ -504,7 +506,7 @@ def visualize_det_cv2_part(
             force_color, np.ndarray
         ), "force_color must be list or numpy array"
 
-    font = cv2.FONT_HERSHEY_SIMPLEX
+    font = cv2.QT_FONT_NORMAL
     font_thickness = 1
     line_thickness = line_thickness
 
@@ -520,11 +522,22 @@ def visualize_det_cv2_part(
         print("boxes with unsupported type, boxes must be ndarray or list.")
 
     if class_names is None or len(class_names) == 0:
-        # not using background
         class_names = coco_label_map_list[1:]
-
+    else:
+        if cls_ids is None:
+            # not class id, using default name, assue only 1 class
+            if class_names is None:
+                class_names = ['object']
+            if class_names[0] not in dynamic_cls_name_color_map.keys():
+                dynamic_cls_name_color_map[class_names[0]] = colors(np.random.choice(global_random_choices_for_u))
+            force_color = [dynamic_cls_name_color_map[class_names[0]]]
+            # class_names.insert(0, 'none')
+    
     for i in range(n_boxes):
-        cls_id = int(cls_ids[i])
+        if cls_ids is not None:
+            cls_id = int(cls_ids[i])
+        else:
+            cls_id = 0 # fake id, assume just one class
         if cls_id != background_id:
             if scores is not None:
                 if scores[i] > thresh:
@@ -587,20 +600,27 @@ def visualize_det_cv2_part(
                             n = class_names[min(cls_id, len(force_color) - 1)]
                         else:
                             n = class_names[cls_id]
-                        text_label = "{} {:.1f}%".format(n, scores[i] * 100)
+                        if score_percent:
+                            text_label = "{} {:.1f}%".format(n, scores[i] * 100)
+                        else:
+                            text_label = "{} {:.2f}".format(n, scores[i])
                     else:
-                        text_label = "{} {:.1f}%".format(cls_id, scores[i] * 100)
+                        if score_percent:
+                            text_label = "{} {:.1f}%".format(cls_id, scores[i] * 100)
+                        else:
+                            text_label = "{} {:.2f}".format(n, scores[i])
 
                     (ret_val, _) = cv2.getTextSize(
                         text_label, font, font_scale, font_thickness
                     )
                     # txt_bottom_left = (x1+4, y1-4)
-                    txt_bottom_left = (x1, y1 - 6)  # make text a little higher
+                    delta = 4
+                    txt_bottom_left = (x1, y1 - delta)  # make text a little higher
                     if transparent:
                         cv2.rectangle(
                             img_mask,
-                            (txt_bottom_left[0], txt_bottom_left[1] - ret_val[1] - 6),
-                            (txt_bottom_left[0] + ret_val[0], txt_bottom_left[1] + 6),
+                            (txt_bottom_left[0], txt_bottom_left[1] - ret_val[1] - delta),
+                            (txt_bottom_left[0] + ret_val[0], txt_bottom_left[1] + delta),
                             unique_color,
                             -1,
                             cv2.LINE_AA,
@@ -608,8 +628,8 @@ def visualize_det_cv2_part(
                     else:
                         cv2.rectangle(
                             img,
-                            (txt_bottom_left[0], txt_bottom_left[1] - ret_val[1] - 6),
-                            (txt_bottom_left[0] + ret_val[0], txt_bottom_left[1] + 6),
+                            (txt_bottom_left[0], txt_bottom_left[1] - ret_val[1] - delta),
+                            (txt_bottom_left[0] + ret_val[0], txt_bottom_left[1] + delta),
                             unique_color,
                             -1,
                             cv2.LINE_AA,
@@ -730,7 +750,7 @@ def visualize_det_cv2_part(
         )
 
     if transparent:
-        img = cv2.addWeighted(img_mask, 0.5, img, 0.9, 0.1)
+        img = cv2.addWeighted(img_mask, 0.9, img, 0.9, 0.9)
 
     if is_show:
         cv2.imshow("image", img)
